==> knative-model-6.4.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaSASLSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KafkaSASLSpecFluentImpl<A extends KafkaSASLSpecFluent<A>> extends BaseFluent<A> implements KafkaSASLSpecFluent<A>{
  public KafkaSASLSpecFluentImpl() {
  }
  public KafkaSASLSpecFluentImpl(KafkaSASLSpec instance) {
    this.withEnable(instance.getEnable()); 
    this.withPassword(instance.getPassword()); 
    this.withType(instance.getType()); 
    this.withUser(instance.getUser()); 
  }
  private Boolean enable;
  private SecretValueFromSourceBuilder password;
  private SecretValueFromSourceBuilder type;
  private SecretValueFromSourceBuilder user;
  public Boolean getEnable() {
    return this.enable;
  }
  public A withEnable(Boolean enable) {
    this.enable=enable; return (A) this;
  }
  public Boolean hasEnable() {
    return this.enable != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPassword instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getPassword() {
    return this.password!=null ?this.password.build():null;
  }
  public SecretValueFromSource buildPassword() {
    return this.password!=null ?this.password.build():null;
  }
  public A withPassword(SecretValueFromSource password) {
    _visitables.get("password").remove(this.password);
    if (password!=null){ this.password= new SecretValueFromSourceBuilder(password); _visitables.get("password").add(this.password);} else { this.password = null; _visitables.get("password").remove(this.password); } return (A) this;
  }
  public Boolean hasPassword() {
    return this.password != null;
  }
  public KafkaSASLSpecFluent.PasswordNested<A> withNewPassword() {
    return new KafkaSASLSpecFluentImpl.PasswordNestedImpl();
  }
  public KafkaSASLSpecFluent.PasswordNested<A> withNewPasswordLike(SecretValueFromSource item) {
    return new KafkaSASLSpecFluentImpl.PasswordNestedImpl(item);
  }
  public KafkaSASLSpecFluent.PasswordNested<A> editPassword() {
    return withNewPasswordLike(getPassword());
  }
  public KafkaSASLSpecFluent.PasswordNested<A> editOrNewPassword() {
    return withNewPasswordLike(getPassword() != null ? getPassword(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaSASLSpecFluent.PasswordNested<A> editOrNewPasswordLike(SecretValueFromSource item) {
    return withNewPasswordLike(getPassword() != null ? getPassword(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildType instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getType() {
    return this.type!=null ?this.type.build():null;
  }
  public SecretValueFromSource buildType() {
    return this.type!=null ?this.type.build():null;
  }
  public A withType(SecretValueFromSource type) {
    _visitables.get("type").remove(this.type);
    if (type!=null){ this.type= new SecretValueFromSourceBuilder(type); _visitables.get("type").add(this.type);} else { this.type = null; _visitables.get("type").remove(this.type); } return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public KafkaSASLSpecFluent.TypeNested<A> withNewType() {
    return new KafkaSASLSpecFluentImpl.TypeNestedImpl();
  }
  public KafkaSASLSpecFluent.TypeNested<A> withNewTypeLike(SecretValueFromSource item) {
    return new KafkaSASLSpecFluentImpl.TypeNestedImpl(item);
  }
  public KafkaSASLSpecFluent.TypeNested<A> editType() {
    return withNewTypeLike(getType());
  }
  public KafkaSASLSpecFluent.TypeNested<A> editOrNewType() {
    return withNewTypeLike(getType() != null ? getType(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaSASLSpecFluent.TypeNested<A> editOrNewTypeLike(SecretValueFromSource item) {
    return withNewTypeLike(getType() != null ? getType(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildUser instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getUser() {
    return this.user!=null ?this.user.build():null;
  }
  public SecretValueFromSource buildUser() {
    return this.user!=null ?this.user.build():null;
  }
  public A withUser(SecretValueFromSource user) {
    _visitables.get("user").remove(this.user);
    if (user!=null){ this.user= new SecretValueFromSourceBuilder(user); _visitables.get("user").add(this.user);} else { this.user = null; _visitables.get("user").remove(this.user); } return (A) this;
  }
  public Boolean hasUser() {
    return this.user != null;
  }
  public KafkaSASLSpecFluent.UserNested<A> withNewUser() {
    return new KafkaSASLSpecFluentImpl.UserNestedImpl();
  }
  public KafkaSASLSpecFluent.UserNested<A> withNewUserLike(SecretValueFromSource item) {
    return new KafkaSASLSpecFluentImpl.UserNestedImpl(item);
  }
  public KafkaSASLSpecFluent.UserNested<A> editUser() {
    return withNewUserLike(getUser());
  }
  public KafkaSASLSpecFluent.UserNested<A> editOrNewUser() {
    return withNewUserLike(getUser() != null ? getUser(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaSASLSpecFluent.UserNested<A> editOrNewUserLike(SecretValueFromSource item) {
    return withNewUserLike(getUser() != null ? getUser(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KafkaSASLSpecFluentImpl that = (KafkaSASLSpecFluentImpl) o;
    if (enable != null ? !enable.equals(that.enable) :that.enable != null) return false;
    if (password != null ? !password.equals(that.password) :that.password != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (user != null ? !user.equals(that.user) :that.user != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(enable,  password,  type,  user,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (enable != null) { sb.append("enable:"); sb.append(enable + ","); }
    if (password != null) { sb.append("password:"); sb.append(password + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (user != null) { sb.append("user:"); sb.append(user); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnable() {
    return withEnable(true);
  }
  class PasswordNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaSASLSpecFluent.PasswordNested<N>> implements KafkaSASLSpecFluent.PasswordNested<N>,Nested<N>{
    PasswordNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    PasswordNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaSASLSpecFluentImpl.this.withPassword(builder.build());
    }
    public N endPassword() {
      return and();
    }
    
  }
  class TypeNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaSASLSpecFluent.TypeNested<N>> implements KafkaSASLSpecFluent.TypeNested<N>,Nested<N>{
    TypeNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    TypeNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaSASLSpecFluentImpl.this.withType(builder.build());
    }
    public N endType() {
      return and();
    }
    
  }
  class UserNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaSASLSpecFluent.UserNested<N>> implements KafkaSASLSpecFluent.UserNested<N>,Nested<N>{
    UserNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    UserNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaSASLSpecFluentImpl.this.withUser(builder.build());
    }
    public N endUser() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaSASLSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KafkaSASLSpecFluentImpl<A extends KafkaSASLSpecFluent<A>> extends BaseFluent<A> implements KafkaSASLSpecFluent<A>{
  public KafkaSASLSpecFluentImpl() {
  }
  public KafkaSASLSpecFluentImpl(KafkaSASLSpec instance) {
    if (instance != null) {
      this.withEnable(instance.getEnable());
      this.withPassword(instance.getPassword());
      this.withType(instance.getType());
      this.withUser(instance.getUser());
    }
  }
  private Boolean enable;
  private SecretValueFromSourceBuilder password;
  private SecretValueFromSourceBuilder type;
  private SecretValueFromSourceBuilder user;
  public Boolean getEnable() {
    return this.enable;
  }
  public A withEnable(Boolean enable) {
    this.enable=enable; return (A) this;
  }
  public Boolean hasEnable() {
    return this.enable != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPassword instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getPassword() {
    return this.password!=null ?this.password.build():null;
  }
  public SecretValueFromSource buildPassword() {
    return this.password!=null ?this.password.build():null;
  }
  public A withPassword(SecretValueFromSource password) {
    _visitables.get("password").remove(this.password);
    if (password!=null){ this.password= new SecretValueFromSourceBuilder(password); _visitables.get("password").add(this.password);} else { this.password = null; _visitables.get("password").remove(this.password); } return (A) this;
  }
  public Boolean hasPassword() {
    return this.password != null;
  }
  public KafkaSASLSpecFluentImpl.PasswordNested<A> withNewPassword() {
    return new KafkaSASLSpecFluentImpl.PasswordNestedImpl();
  }
  public KafkaSASLSpecFluentImpl.PasswordNested<A> withNewPasswordLike(SecretValueFromSource item) {
    return new KafkaSASLSpecFluentImpl.PasswordNestedImpl(item);
  }
  public KafkaSASLSpecFluentImpl.PasswordNested<A> editPassword() {
    return withNewPasswordLike(getPassword());
  }
  public KafkaSASLSpecFluentImpl.PasswordNested<A> editOrNewPassword() {
    return withNewPasswordLike(getPassword() != null ? getPassword(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaSASLSpecFluentImpl.PasswordNested<A> editOrNewPasswordLike(SecretValueFromSource item) {
    return withNewPasswordLike(getPassword() != null ? getPassword(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildType instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getType() {
    return this.type!=null ?this.type.build():null;
  }
  public SecretValueFromSource buildType() {
    return this.type!=null ?this.type.build():null;
  }
  public A withType(SecretValueFromSource type) {
    _visitables.get("type").remove(this.type);
    if (type!=null){ this.type= new SecretValueFromSourceBuilder(type); _visitables.get("type").add(this.type);} else { this.type = null; _visitables.get("type").remove(this.type); } return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public KafkaSASLSpecFluentImpl.TypeNested<A> withNewType() {
    return new KafkaSASLSpecFluentImpl.TypeNestedImpl();
  }
  public KafkaSASLSpecFluentImpl.TypeNested<A> withNewTypeLike(SecretValueFromSource item) {
    return new KafkaSASLSpecFluentImpl.TypeNestedImpl(item);
  }
  public KafkaSASLSpecFluentImpl.TypeNested<A> editType() {
    return withNewTypeLike(getType());
  }
  public KafkaSASLSpecFluentImpl.TypeNested<A> editOrNewType() {
    return withNewTypeLike(getType() != null ? getType(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaSASLSpecFluentImpl.TypeNested<A> editOrNewTypeLike(SecretValueFromSource item) {
    return withNewTypeLike(getType() != null ? getType(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildUser instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getUser() {
    return this.user!=null ?this.user.build():null;
  }
  public SecretValueFromSource buildUser() {
    return this.user!=null ?this.user.build():null;
  }
  public A withUser(SecretValueFromSource user) {
    _visitables.get("user").remove(this.user);
    if (user!=null){ this.user= new SecretValueFromSourceBuilder(user); _visitables.get("user").add(this.user);} else { this.user = null; _visitables.get("user").remove(this.user); } return (A) this;
  }
  public Boolean hasUser() {
    return this.user != null;
  }
  public KafkaSASLSpecFluentImpl.UserNested<A> withNewUser() {
    return new KafkaSASLSpecFluentImpl.UserNestedImpl();
  }
  public KafkaSASLSpecFluentImpl.UserNested<A> withNewUserLike(SecretValueFromSource item) {
    return new KafkaSASLSpecFluentImpl.UserNestedImpl(item);
  }
  public KafkaSASLSpecFluentImpl.UserNested<A> editUser() {
    return withNewUserLike(getUser());
  }
  public KafkaSASLSpecFluentImpl.UserNested<A> editOrNewUser() {
    return withNewUserLike(getUser() != null ? getUser(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaSASLSpecFluentImpl.UserNested<A> editOrNewUserLike(SecretValueFromSource item) {
    return withNewUserLike(getUser() != null ? getUser(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KafkaSASLSpecFluentImpl that = (KafkaSASLSpecFluentImpl) o;
    if (!java.util.Objects.equals(enable, that.enable)) return false;

    if (!java.util.Objects.equals(password, that.password)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(user, that.user)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(enable,  password,  type,  user,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (enable != null) { sb.append("enable:"); sb.append(enable + ","); }
    if (password != null) { sb.append("password:"); sb.append(password + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (user != null) { sb.append("user:"); sb.append(user); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnable() {
    return withEnable(true);
  }
  class PasswordNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaSASLSpecFluentImpl.PasswordNested<N>> implements KafkaSASLSpecFluentImpl.PasswordNested<N>,Nested<N>{
    PasswordNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    PasswordNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaSASLSpecFluentImpl.this.withPassword(builder.build());
    }
    public N endPassword() {
      return and();
    }
    
  }
  class TypeNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaSASLSpecFluentImpl.TypeNested<N>> implements KafkaSASLSpecFluentImpl.TypeNested<N>,Nested<N>{
    TypeNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    TypeNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaSASLSpecFluentImpl.this.withType(builder.build());
    }
    public N endType() {
      return and();
    }
    
  }
  class UserNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaSASLSpecFluentImpl.UserNested<N>> implements KafkaSASLSpecFluentImpl.UserNested<N>,Nested<N>{
    UserNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    UserNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaSASLSpecFluentImpl.this.withUser(builder.build());
    }
    public N endUser() {
      return and();
    }
    
  }
  
}
